package unicode::View::TT;

use strict;
use base 'Catalyst::View::TT';

__PACKAGE__->config(TEMPLATE_EXTENSION => '.tt');

=head1 NAME

unicode::View::TT - TT View for unicode

=head1 DESCRIPTION

TT View for unicode. 

=head1 AUTHOR

=head1 SEE ALSO

L<unicode>

Carl Franks

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
